# -*- coding: utf-8 -*-

# pyramid-helpers -- Helpers to develop Pyramid applications
# By: Cyril Lacoux <clacoux@easter-eggs.com>
#
# Copyright (C) 2011-2015 Cyril Lacoux, Easter-eggs
# @app_url@
#
# This file is part of pyramid-helpers.
#
# pyramid-helpers is free software; you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# pyramid-helpers is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


from logging import getLogger

from pyramid.compat import json
from pyramid.httpexceptions import HTTPInternalServerError

log = getLogger(__name__)


def csv_renderer_factory(info):
    """ CSV renderer for Pyramid """

    def _render(value, system):
        request = system.get('request')
        _ = request.translate

        try:
            result = [
                value['format'].format(**row)
                for row in value['values']
            ]
            result.insert(0, value['header'])
            result = u'\n'.join(result)
        except:
            log.exception('Could not convert view response to CSV')
            raise HTTPInternalServerError(explanation=_(u'Could not convert view response to CSV'))

        filename = value.get('filename', u'result.csv')

        # Set content type
        request.response.content_type = 'text/csv; charset="utf-8"'
        request.response.content_disposition = u'attachment; filename="{0}"'.format(filename)
        return result

    return _render


def json_renderer_factory(info):
    """
    Custom json renderer with callback suppport
    """
    def _render(value, system):
        callback = None
        request = system.get('request')

        result = json.dumps(value, default=str)

        if callback:
            request.response.content_type = 'application/javascript; charset="utf-8"'
            result = u'%s(%s)' % (callback, result)
        else:
            request.response.content_type = 'application/json; charset="utf-8"'
        return result

    return _render
