# -*- coding: utf-8 -*-

# pyramid-helpers -- Helpers to develop Pyramid applications
# By: Cyril Lacoux <clacoux@easter-eggs.com>
#
# Copyright (C) 2011-2015 Cyril Lacoux, Easter-eggs
# @app_url@
#
# This file is part of pyramid-helpers.
#
# pyramid-helpers is free software; you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# pyramid-helpers is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


""" Database initialization script """

import datetime
import os
import sys
import transaction

from sqlalchemy import engine_from_config

from pyramid.paster import get_appsettings
from pyramid.paster import setup_logging

from pyramid_helpers.models import Article
from pyramid_helpers.models import Base
from pyramid_helpers.models import DBSession
from pyramid_helpers.models import Group
from pyramid_helpers.models import User


def usage(argv):
    cmd = os.path.basename(argv[0])
    print('usage: %s <config_uri>\n'
          '(example: "%s development.ini")' % (cmd, cmd))
    sys.exit(1)


def main(argv=sys.argv):
    if len(argv) != 2:
        usage(argv)
    config_uri = argv[1]
    setup_logging(config_uri)
    settings = get_appsettings(config_uri, 'pyramid-helpers')
    engine = engine_from_config(settings, 'sqlalchemy.')
    DBSession.configure(bind=engine)
    Base.metadata.create_all(engine)

    # Popuplate table users
    with transaction.manager:
        for name in [u'admin', u'guest']:
            group = Group()
            group.name = name
            group.description = u'{0} group description'.format(name)

            user = User()
            user.username = name
            user.groups = [group, ]
            user.set_password(name)

            DBSession.add(user)

    # Popuplate table articles
    with transaction.manager:
        utcnow = datetime.datetime.utcnow()
        author = DBSession.query(User).get(1)

        for i in range(1, 100):
            article = Article()
            article.author = author
            article.creation_date = utcnow
            article.modification_date = utcnow
            article.title = u'Article #%d' % i
            article.text = u'Text of article #%d' % i
            article.status = u'published'

            DBSession.add(article)
