<%!
from webhelpers.html import tags

def coerce_bool(arg):
    if isinstance(arg, basestring):
        return eval(arg)
    elif isinstance(arg, bool):
        return arg
    else:
        raise ArgumentError("%r could not be coerced to boolean" % arg)

def html5_data_attrs(**attrs):
    for key in attrs:
        if key.startswith('data_'):
            attrs['data-{0}'.format(key[5:])] = attrs.pop(key)
    return attrs
%>\
<%doc>

    Mako form tag library.

    Adapts Pylons' webhelpers.html functions into <%defs> which are readily usable via <%call>.

    The <%call> tags themselves can be more pleasantly used in templates using a
    preprocessor such as process_tags(), which converts XML-style tags into <%call> tags.

</%doc>

<%def name="errors(name, extra_class=None)">\
<%doc>
    Given a field name, produce a stylized error message from the current
    form errors collection, if one is present.  Else render nothing.
</%doc>
<% error = form_ctx['current'].error(name) %>\
% if error:
<div class="alert alert-danger input-error${u' %s' % extra_class if extra_class else u''}">
    <button type="button" class="close" data-dismiss="alert" aria-hidden="true">&times;</button>
    ${error}
</div>
% endif
</%def>

<%def name="form(name, action=None, multipart=False, **attrs)">
<%doc>
    Render an HTML <form> tag - the body contents will be rendered within.

        name - the name of the form stored in request attribute
        action - url to be POSTed to
</%doc>
<%
    # Get form instance
    assert name in forms, 'Invalid form name {0}'.format(name)
    form_ctx['current'] = forms[name]
%>\
${tags.form(action or request.path_qs, multipart=coerce_bool(multipart), name=name, **html5_data_attrs(**attrs))}
% if form_ctx['current'].csrf_token:
    ${tags.hidden('_csrf_token', value=csrf_token)}
% endif
${caller.body()}\
${tags.end_form()}\
<%
    del form_ctx['current']
%>\
</%def>

<%def name="text(name, **attrs)">\
<%doc>
    Render an HTML <input type="text"> tag.
</%doc>
${tags.text(name, value=form_ctx['current'].value(name), **html5_data_attrs(**attrs))}\
${errors(name)}\
</%def>

<%def name="upload(name, **attrs)">\
<%doc>
    Render an HTML <file> tag.
</%doc>
${tags.file(name, **html5_data_attrs(**attrs))}\
${errors(name)}\
</%def>

<%def name="hidden(name, **attrs)">\
<%doc>
    Render an HTML <input type="hidden"> tag.
</%doc>
${tags.hidden(name, value=form_ctx['current'].value(name), **html5_data_attrs(**attrs))}\
${errors(name)}
</%def>

<%def name="password(name, **attrs)">\
<%doc>
    Render an HTML <input type="password"> tag.
</%doc>
${tags.password(name, value=form_ctx['current'].value(name), **html5_data_attrs(**attrs))}\
${errors(name)}\
</%def>

<%def name="textarea(name, **attrs)">\
<%doc>
    Render an HTML <textarea></textarea> tag pair with embedded content.
</%doc>
${tags.textarea(name, content=form_ctx['current'].value(name), **html5_data_attrs(**attrs))}\
${errors(name)}\
</%def>

<%def name="select(name, **attrs)">\
<%doc>
    Render an HTML <select> tag.  Options within the tag
    are generated using the "option" %def.
</%doc>
<%
    form_ctx['select_options'] = []
    capture(caller.body)
%>\
${tags.select(name, form_ctx['current'].value(name), form_ctx['select_options'], **html5_data_attrs(**attrs))}\
${errors(name)}\
<%
    del form_ctx['select_options']
%>\
</%def>

<%def name="optgroup(label)">\
<%doc>
    Render an HTML <optgroup> tag.  This is meant to be used with
    the "select" %def and produces a special return value specific to
    usage with that function.
</%doc>
<%
    options = form_ctx['select_options']

    form_ctx['select_options'] = []
    capture(caller.body)

    options.append((form_ctx['select_options'], label))
    form_ctx['select_options'] = options
%>\
</%def>

<%def name="option(value)">\
<%doc>
    Render an HTML <option> tag.  This is meant to be used with
    the "select" %def and produces a special return value specific to
    usage with that function.
</%doc>
<%
    form_ctx['select_options'].append((value, capture(caller.body).strip()))
%>\
</%def>

<%def name="checkbox(name, value='true', **attrs)">\
<%doc>
    Render an HTML <checkbox> tag.  The value is rendered as 'true'
    by default for usage with the StringBool validator.
</%doc>
<%
    data = form_ctx['current'].value(name)
    if data in (False, True):
        checked = bool(value) == data
    elif isinstance(data, list):
        checked = str(value) in map(str, data)
    else:
        checked = str(value) == str(data)
%>\
${tags.checkbox(name, value, checked=checked, **html5_data_attrs(**attrs))}\
${errors(name)}
</%def>

<%def name="radio(name, value='true', **attrs)">\
<%doc>
    Render an HTML <radio> tag.
</%doc>
<%
    data = form_ctx['current'].value(name)
    if isinstance(data, bool):
        checked = bool(value) == data
    elif isinstance(data, list):
        checked = value in data
    else:
        checked = str(value) == str(data)
%>\
${tags.radio(name, value, checked=checked, **html5_data_attrs(**attrs))}\
${errors(name)}
</%def>

<%def name="submit(value=None, name=None, **attrs)">\
<%doc>
    Render an HTML <submit> tag.
</%doc>
${tags.submit(name=name, value=value, **html5_data_attrs(**attrs))}\
</%def>
