# Pyramid-Helpers

Pyramid-Helpers is a set of helpers to develop applications using Pyramid framework.

It includes forms, i18n and pagination helpers.


## Dependencies

* python-decorator
* python-mako
* python-pybabel
* python-pyramid
* python-pyramid-tm
* python-sqlalchemy
* python-transaction
* python-weberror
* python-webhelpers
* python-zope.sqlalchemy


## Installation
```
$ ./setup.py compile_catalog
$ sudo ./setup.py develop --no-deps
$ initialize_pyramid-helpers_db development.ini
```

or
```
$ ./setup.py compile_catalog
$ sudo ./setup.py install --no-deps
$ initialize_pyramid-helpers_db development.ini
```


## Usage
```
$ pserve --reload development.ini
```


## Files list

```
.
├── CHANGES.txt
├── development.ini
├── MANIFEST.in
├── production.ini
├── README.md
├── setup.cfg
├── setup.py
└── pyramid_helpers
    ├── __init__.py                     demo app config
    ├── auth.py                         auth helpers for demo app
    ├── errors.py                       error views for demo app (NotFound, Forbidden)
    ├── models.py                       SQLAlchemy model for demo app
    ├── paginate.py                     pagination class, decorator and setup
    ├── resources.py                    basic resource file for demo app
    ├── forms
    │   ├── __init__.py                 form class, decorator and setup, largely inspired from formhelpers[1]
    │   ├── auth.py                     formencode schema for authentication for demo app
    │   └── articles.py                 formencode schemas for articles for demo app
    ├── i18n.py                         i18n setup and helpers
    ├── locale
    │   ├── fr
    │   │   └── LC_MESSAGES
    │   │       └── pyramid-helpers.po
    │   └── pyramid-helpers.pot
    ├── scripts
    │   ├── __init__.py
    │   └── initializedb.py
    ├── static
    │   ├── pyramid-helpers.css         demo app stylesheet
    │   └── pyramid-helpers.js          demo app javascript
    ├── templates
    │   ├── articles
    │   │   ├── edit.mako
    │   │   ├── index.mako
    │   │   └── view.mako
    │   ├── confirm.mako
    │   ├── errors.mako
    │   ├── form-tags.mako              Mako templates for forms rendering - derivates from formhelpers[1]
    │   ├── login.mako
    │   ├── paginate.mako               Mako templates for pagination rendering
    │   └── site.mako
    └── views
        ├── __init__.py
        └── articles.py
```


## Usefull documentation

* http://docs.pylonsproject.org/projects/pyramid/en/latest/
* http://docs.pylonsproject.org/projects/pyramid/en/latest/api.html
* http://techspot.zzzeek.org/2008/07/01/better-form-generation-with-mako-and-pylons/
